# A python wrapper for GSL cubic spline interpolation in C.

This extension should be built from the gwsurrogate-level setup.py
script. However, if you wish to do it locally, then

Do ```python setup.py build_ext --inplace```
